@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-23'; # DATE
+our $DATE = '2021-07-31'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Bencher-Scenario'; # DIST
-our $VERSION = '0.248'; # VERSION
+our $VERSION = '0.249'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -223,7 +223,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
 
     my @modules = Bencher::Backend::_get_participant_modules($scenario);
 
-    # add Sample Benchmark Results section
+    # add Benchmark Sample Results section
     my @bench_res;
     my $table_num = 0;
     {
@@ -307,13 +307,15 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
                     my $fres = Bencher::Backend::format_result($split_item->[1]);
                     $fres =~ s/^/ /gm;
                     $table_num++;
+                    push @pod, "Result formatted as table:\n\n";
                     push @pod, " #table$table_num#\n", " ", dmp($split_item->[0]), "\n$fres\n";
                     {
                         $fres = Bencher::Backend::format_result($split_item->[1], undef, {render_as_benchmark_pm=>1});
                         $fres =~ s/^/ /gm;
-                        push @pod, "Formatted as L<Benchmark.pm|Benchmark> result:\n\n$fres\n";
+                        push @pod, "Result formatted in L<Benchmark.pm|Benchmark> style:\n\n$fres\n";
                     }
                     push @pod, __html_result($bench_res, $table_num) if $self->gen_html_tables;
+                    push @pod, "Result presented as chart:\n\n";
                     $self->_gen_chart($tempdir, $input, \@pod, $split_item->[1], $table_num);
                     push @bench_res, $split_item->[1];
                 }
@@ -322,13 +324,16 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
                 my $fres = Bencher::Backend::format_result($bench_res);
                 $fres =~ s/^/ /gm;
                 $table_num++;
-                push @pod, "$bench->{title}:\n\n #table$table_num#\n$fres\n\n";
+                push @pod, "$bench->{title}:\n\n";
+                push @pod, "Result formatted as table:\n\n";
+                push @pod, " #table$table_num#\n$fres\n\n";
                 {
                     $fres = Bencher::Backend::format_result($bench_res, undef, {render_as_benchmark_pm=>1});
                     $fres =~ s/^/ /gm;
-                    push @pod, "Formatted as L<Benchmark.pm|Benchmark> result:\n\n$fres\n";
+                    push @pod, "Result formatted in L<Benchmark.pm|Benchmark> style:\n\n$fres\n";
                 }
                 push @pod, __html_result($bench_res, $table_num) if $self->gen_html_tables;
+                push @pod, "Result presented as chart:\n\n";
                 $self->_gen_chart($tempdir, $input, \@pod, $bench_res, $table_num);
                 push @bench_res, $bench_res;
             }
@@ -345,13 +350,16 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
             $fres = Bencher::Backend::format_result($bench_res2);
             $fres =~ s/^/ /gm;
             $table_num++;
-            push @pod, "Benchmark module startup overhead (C<< bencher ".($is_cpanmodules ? "--cpanmodules-module $cpanmodules_name" : "-m $scenario_name")." --module-startup >>):\n\n #table$table_num#\n", $fres, "\n\n";
+            push @pod, "Benchmark module startup overhead (C<< bencher ".($is_cpanmodules ? "--cpanmodules-module $cpanmodules_name" : "-m $scenario_name")." --module-startup >>):\n\n";
+            push @pod, "Result formatted as table:\n\n";
+            push @pod, " #table$table_num#\n", $fres, "\n\n";
             {
                 $fres = Bencher::Backend::format_result($bench_res2, undef, {render_as_benchmark_pm=>1});
                 $fres =~ s/^/ /gm;
-                push @pod, "Formatted as L<Benchmark.pm|Benchmark> result:\n\n$fres\n";
+                push @pod, "Result formatted in L<Benchmark.pm|Benchmark> style:\n\n$fres\n";
             }
             push @pod, __html_result($bench_res2, $table_num) if $self->gen_html_tables;
+            push @pod, "Result presented as chart:\n\n";
             $self->_gen_chart($tempdir, $input, \@pod, $bench_res2, $table_num);
         }
 
@@ -360,7 +368,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
         }
 
         $self->add_text_to_section(
-            $document, join("", @pod), 'SAMPLE BENCHMARK RESULTS',
+            $document, join("", @pod), 'BENCHMARK SAMPLE RESULTS',
             {
                 after_section => ['BENCHMARKED MODULES', 'SYNOPSIS'],
                 before_section => 'DESCRIPTION',
@@ -402,7 +410,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
             $document, join("", @pod), 'BENCHMARKED MODULES',
             {
                 after_section => 'SYNOPSIS',
-                before_section => ['SAMPLE BENCHMARK RESULTS', 'DESCRIPTION'],
+                before_section => ['BENCHMARK SAMPLE RESULTS', 'DESCRIPTION'],
             });
     }
 
@@ -462,7 +470,7 @@ sub _process_bencher_scenario_or_acme_cpanmodules_module {
             $document, join("", @pod), 'BENCHMARK PARTICIPANTS',
             {
                 after_section => ['BENCHMARKED MODULES'],
-                before_section => ['SAMPLE BENCHMARK RESULTS'],
+                before_section => ['BENCHMARK SAMPLE RESULTS'],
             });
     }
 
@@ -670,7 +678,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.248 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2021-07-23.
+This document describes version 0.249 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2021-07-31.
 
 =head1 SYNOPSIS
 
@@ -697,7 +705,7 @@ Only for C<lib/Bencher/Scenario/*> module files.
 
 =item * Add a Benchmark Participants section containing list of participants from the scenario
 
-=item * Add a Sample Benchmark Results containing result from a bencher run
+=item * Add a Benchmark Sample Results containing result from a bencher run
 
 Both normal benchmark and a separate module startup benchmark (if eligible) are
 run and shown.
@@ -706,7 +714,7 @@ run and shown.
 
 =item * Create C<lib/Bencher/ScenarioR/*> or C<lib/Acme/CPANModules_ScenarioR/*> module files that contain sample benchmark result data
 
-These module files contain the raw data, while the Sample Benchmark Results POD
+These module files contain the raw data, while the Benchmark Sample Results POD
 section of the scenario module contains the formatted result. The raw data might
 be useful later. For example I'm thinking of adding a utility later, perhaps in
 the form of an L<lcpan> subcommand, that can guess whether a module is
